sphinx_copybutton: Add a copy button to each of your code cells
===============================================================

Description
-----------

Add a copy button to each of your code cells

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/sphinx-copybutton/

